import Vue from 'vue'

import Cookies from 'js-cookie'

import 'normalize.css/normalize.css' // a modern alternative to CSS resets

import Element from 'element-ui'
import './styles/element-variables.scss'

import '@/styles/index.scss' // global css

import App from './App'
import store from './store'
import router from './router'

import './icons' // icon
import './permission' // permission control
import './utils/error-log' // error log
import permission2 from './directive/permission/permission2'

import * as filters from './filters' // global filters

/**
 * If you don't want to use mock-server
 * you want to use MockJs for mock api
 * you can execute: mockXHR()
 *
 * Currently MockJs will be used in the production environment,
 * please remove it before going online! ! !
 */
import { mockXHR } from '../mock'
import VueAMap from 'vue-amap'

Vue.use(VueAMap)
Vue.directive('permission2', permission2)
Vue.config.productionTip = false
// 初始化vue-amap
VueAMap.initAMapApiLoader({
  // 高德key
  key: '2fec7f1d47f4ba26c9e4ebdcfb7f1303',
  // 插件集合 （插件按需引入）
  plugin: ['AMap.Geolocation', 'AMap.OverView', 'AMap.PlaceSearch', 'AMap.Geocoder'],
  v: '1.4.4'
})
import moment from 'moment'
// 定义一个全局过滤器实现日期格式化
Vue.filter('datrfmt', function(input, fmtstring) { // 当input为时间戳时，需转为Number类型
  // 使用momentjs这个日期格式化类库实现日期的格式化功能
  return moment(input).format(fmtstring)
})
Vue.prototype.$moment = moment

if (process.env.NODE_ENV === 'production') {
  mockXHR()
}

Vue.use(Element, {
  size: Cookies.get('size') || 'medium' // set element-ui default size
})

// register global utility filters
Object.keys(filters).forEach(key => {
  Vue.filter(key, filters[key])
})

Vue.config.productionTip = false

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
