import router, { constantRoutes } from '@/router'
import { getRoutes, getApiPermission } from '@/api/menu'
import Layout from '@/layout'

/**
 * 构建动态路由
 * @param {*} asyncRouterMap 
 */
function filterAsyncRouter(asyncRouterMap) { // 遍历后台传来的路由字符串，转换为组件对象
  const accessedRouters = asyncRouterMap.filter(route => {
    if (route.component) {
      if (route.component === 'Layout') { // Layout组件特殊处理
        route.component = Layout
      } else {
        let comp;
        try {
          comp = require('@/views/' + route.component + '.vue').default
        } catch (e) {
          console.error(e)
          return false
        }
        if (router.type === 'router') {
          route.components = {
            aaa: comp
          }
        } else {
          route.component = comp
        }
      }
    }
    if (route.children && route.children.length) {
      route.children = filterAsyncRouter(route.children)
    }
    return true
  })
  return accessedRouters
}

const state = {
  routes: [],
  addRoutes: []
}

const mutations = {
  SET_ROUTES: (state, routes) => {
    state.addRoutes = routes
    state.routes = constantRoutes.concat(routes)
    
  }
}

const actions = {
  /**
   * 构建动态路由 获取动态api权限
   * @param {*} param0 
   * @returns accessedRoutes 动态路由对象
   */
  generateRoutes({ commit }) {
    return new Promise(resolve => {
      getRoutes().then(response => {
        const route = response.data
        let accessedRoutes =  filterAsyncRouter(route)
        getApiPermission().then(res => {
          const permission = res.data
          window.localStorage.setItem('permission', JSON.stringify(permission))
          commit('SET_ROUTES', accessedRoutes)
        resolve(accessedRoutes)
        })
      })
    })
  },
  /**
   * 清除动态路由
   * @param {*}} param0 
   */
  resetRouters({ commit }) {
    commit('SET_ROUTES', [])
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions
}
