import { isNotNULL, pustData, isRealNum, dataHandlePZA } from '@/utils/validate'

/**
 * 参数验证是否为空
 * @param {Array} form
 * @returns {String}
 */
export function formIsNull(form) {
  var quaVeri = ''
  if (!isNotNULL(form.smsLabel)) {
    quaVeri += '短信标签不能为空！'
  }
  if (!isNotNULL(form.storeUser)) {
    quaVeri += '门店账号不能为空！'
  }
  if (!isRealNum(form.storeUser * 1)) {
    quaVeri += '门店账号只能是数字！'
  }
  if (!isNotNULL(form.smsNoticeTemplate)) {
    quaVeri += '短信通知模板不能为空！'
  }
  if (!isNotNULL(form.storeName)) {
    quaVeri += '门店名称不能为空！'
  }
  if (!isNotNULL(form.noticeType)) {
    quaVeri += '通知类型不能为空！'
  }
  if (!isNotNULL(form.company)) {
    quaVeri += '所属公司不能为空！'
  }
  if (!isNotNULL(form.customerPhone)) {
    quaVeri += '客服电话不能为空！'
  }
  if (!isNotNULL(form.storeType)) {
    quaVeri += '门店类型不能为空！'
  }
  if (!isNotNULL(form.province) && !isNotNULL(form.city) && !isNotNULL(form.area) && !isNotNULL(form.address)) {
    quaVeri += '联系地址不能为空！'
  }
  if (form.rent === 0) {
    quaVeri += '租金不能为空！'
  }
  if (!isNotNULL(form.leaseStartTime) && !isNotNULL(form.leaseEndTime)) {
    quaVeri += '租赁日期不能为空！'
  } else if (Date.parse(form.leaseStartTime) > Date.parse(form.leaseEndTime)) {
    quaVeri += '租赁开始日期不能大于租赁结束日期！'
  }
  if (!isNotNULL(form.accessAddress)) {
    quaVeri += '取件地址不能为空！'
  }
  if (form.accessAddress.length > 20) {
    quaVeri += '取件地址过长！'
  }
  if (!isNotNULL(form.businessStartTime) && !isNotNULL(form.businessEndTime)) {
    quaVeri += '营业时间不能为空！'
  } else if (Date.parse(form.businessStartTime) > Date.parse(form.businessEndTime)) {
    quaVeri += '营业开始时间不能大于营业结束时间！'
  }
  if (!isNotNULL(form.siteManager)) {
    quaVeri += '站点负责人不能为空！'
  }
  if (form.messageRate === 0) {
    quaVeri += '消息费率不能为空！'
  }
  if (!isNotNULL(form.userPhone)) {
    quaVeri += '负责人手机不能为空！'
  }
  if (!isNotNULL(form.userIdCards)) {
    quaVeri += '负责人身份证不能为空！'
  }
  if (isNotNULL(form.uiStartTime) && isNotNULL(form.uiEndTime)) {
    if (Date.parse(form.uiStartTime) > Date.parse(form.uiEndTime)) {
      quaVeri += '承包开始日期不能大于承包结束日期！'
    }
  }
  return quaVeri
}
/**
 * 参数处理
 * @param {Array} form
 * @returns {String}
 */
export function paramHandle(form) {
  var obj = {}
  if (form == null) {
    return ''
  }
  if (form.storeId !== '' && form.storeId != null) {
    obj.id = form.storeId
  }
  obj.userId = form.storeUser // 门店账号
  obj.name = form.storeName // 门店名称
  obj.companyId = form.company // 所属公司
  obj.storeType = form.storeType // 门店类型
  obj.provinceId = form.province // 省
  obj.cityId = form.city // 市
  obj.areaId = form.area // 区
  obj.township = form.township // 镇/街
  obj.townshipId = form.townshipId // 镇/街
  obj.address = form.address // 联系地址
  obj.shortAddress = form.accessAddress // 取件地址
  obj.siduanma = form.code // 四段码
  obj.startTime = form.businessStartTime // 营业开始时间
  obj.endTime = form.businessEndTime // 营业结束时间
  obj.smsPrice = form.messageRate // 消息费率
  obj.smsBalance = form.userBalance // 账户余额
  obj.comSign = form.smsLabel // 短信标签
  obj.templateId = form.smsNoticeTemplate // 短信通知模板
  obj.reminder = form.noticeType // 通知类型
  obj.takeExpressPhone = form.customerPhone // 客服电话
  obj.signBackSwitch = form.expSignReturn // 快件签收回传:[101,102]
  obj.rent = form.rent // 租金
  obj.leaseStartDate = form.leaseStartTime // 租赁日期（开始）
  obj.leaseEndDate = form.leaseEndTime // 租赁日期（结束）
  obj.contractFee = form.contractingCosts // 承包费用
  obj.contractStartDate = form.uiStartTime // 承包日期(开始)
  obj.contractEndDate = form.uiEndTime // 承包日期(结束)
  obj.owner = form.siteManager // 站点负责人
  obj.phone = form.userPhone // 负责人手机
  obj.ownerID = form.userIdCards // 负责人身份证
  obj.ownerAlipayAccount = form.userAlipay // 负责人支付宝
  obj.ownerWechat = form.userWeChat // 负责人微信
  obj.usermail = form.mail // 邮箱
  obj.appid = form.weChatId // 微信公众号ID
  obj.appsecret = form.weChatDeveloperSecret // 公众号开发者秘钥
  obj.msgtempid = form.arrivalNoticeTemplateId // 公众号到件通知模板ID
  obj.signtempid = form.signNoticeTemplateId // 公众号签收通知模板ID
  obj.appOrderLink = form.weChatPlaceOrderUrl // 公众号下单链接
  obj.auditStatus = form.examineStatus // 审核状态
  obj.status = form.useStatus // 使用状态
  obj.smsSendType = form.pushType // 自提短信发送方式（1：自动发送  2：手动发送）
  obj.upExpPhone = form.upExpPhone // 修改快递公司号码
  obj.shelfCount = form.shelfCount // 货架数量
  obj.shelfLayers = form.shelfLayers // 货架层数
  return pustData(obj)
}

/**
 * 参数处理
 * @param {Array} form
 * @returns {String}
 */
export function dataHandle(obj) {
  var form = {}
  if (obj == null) {
    return ''
  }
  form.province = '' // obj.provinceId // 省
  form.city = '' // obj.cityId // 市
  form.area = '' // obj.areaId // 区
  form.areaName = obj.areaName
  form.township = obj.township
  form.townshipId = obj.townshipId // 镇/街道
  if (obj.regionCode != null && obj.regionCode !== '') {
    const data = dataHandlePZA(obj.regionCode)
    form.province = data[0] * 1 // obj.provinceId // 省
    form.city = data[1] * 1 // obj.cityId // 市
    form.area = data[2] * 1 // obj.areaId // 区
  }
  form.storeId = obj.id // 门店编码id
  form.storeUser = obj.userId // 门店账号
  form.storeName = obj.name // 门店名称
  form.company = obj.companyId // 所属公司
  form.storeType = obj.storeType // 门店类型
  form.address = obj.address // 联系地址
  form.accessAddress = obj.shortAddress // 取件地址
  form.code = obj.siduanma // 四段码
  form.businessStartTime = obj.startTime // 营业开始时间
  form.businessEndTime = obj.endTime // 营业结束时间
  form.messageRate = obj.smsPrice // 消息费率
  form.userBalance = obj.smsBalance // 账户余额
  form.smsLabel = obj.comSign // 短信标签
  form.smsNoticeTemplate = obj.templateId // 短信通知模板
  form.noticeType = obj.reminder // 通知类型
  form.customerPhone = obj.takeExpressPhone // 客服电话
  form.expSignReturn = obj.signBackSwitch // 快件签收回传:[101,102]
  form.rent = obj.rent // 租金
  form.leaseStartTime = obj.leaseStartDate // 租赁日期（开始）
  form.leaseEndTime = obj.leaseEndDate // 租赁日期（结束）
  form.contractingCosts = obj.contractFee // 承包费用
  form.uiStartTime = obj.contractStartDate // 承包日期(开始)
  form.uiEndTime = obj.contractEndDate // 承包日期(结束)
  form.siteManager = obj.owner // 站点负责人
  form.userPhone = obj.phone // 负责人手机
  form.userIdCards = obj.ownerID // 负责人身份证
  form.userAlipay = obj.ownerAlipayAccount // 负责人支付宝
  form.userWeChat = obj.ownerWechat // 负责人微信
  form.mail = obj.usermail // 邮箱
  form.weChatId = obj.appid // 微信公众号ID
  form.weChatDeveloperSecret = obj.appsecret // 公众号开发者秘钥
  form.arrivalNoticeTemplateId = obj.msgtempid // 公众号到件通知模板ID
  form.signNoticeTemplateId = obj.signtempid // 公众号签收通知模板ID
  form.weChatPlaceOrderUrl = obj.appOrderLink // 公众号下单链接
  form.examineStatus = obj.auditStatus + '' // 审核状态
  form.useStatus = obj.status + '' // 使用状态
  form.pushType = obj.smsSendType + '' // 自提短信发送方式（1：自动发送  2：手动发送）
  return form
}

/**
 * 门店列表查询条件处理
 * @param {Array} form
 * @returns {String}
 */
export function queryCriteriaHandle(form, pageNumber, pageSize) {
  var obj = {}
  obj.provinceId = form.province // 省/provinceId
  obj.cityId = form.city // 市/cityId
  obj.areaId = form.area // 区/areaId
  obj.storeType = form.type // 门店类型
  obj.status = form.status // 门店状态，
  obj.name = form.storeNames // 门店名称
  obj.owner = form.principal // 负责人
  obj.phone = form.phone // 负责人电话
  obj.pageNumber = pageNumber // 第几页，可不护传，默认第一页
  obj.pageSize = pageSize // 每页多少条数据，可不传默认10条
  obj.id = form.id ? form.id : ''
  return pustData(obj)
}

/**
 * 通过门店id查询门店条件处理
 * @param {Array} form
 * @returns {String}
 */
export function getStoreByIdDataHandle(id) {
  var obj = {}
  obj.id = id // 门店id
  return pustData(obj)
}

/**
 * 充值条件处理
 * @param {Array} form
 * @returns {String}
 */
export function getStoreMoney(id, money) {
  var obj = {}
  obj.id = id // 门店id
  obj.money = money
  return pustData(obj)
}

/**
 * 禁用条件处理
 * @param {Array} form
 * @returns {String}
 */
export function disableStoreDataHandle(id) {
  var obj = {}
  obj.id = id // 门店id
  return pustData(obj)
}

